"""Console script for rstms_vimfix."""

import sys
from pathlib import Path

import click
import click.core

from .exception_handler import ExceptionHandler
from .shell import _shell_completion
from .version import __timestamp__, __version__
from .vimfix import formats, vimfix

header = f"{__name__.split('.')[0]} v{__version__} {__timestamp__}"


def _ehandler(ctx, option, debug):
    ctx.obj = dict(ehandler=ExceptionHandler(debug))
    ctx.obj["debug"] = debug


@click.command("vimfix", context_settings={"auto_envvar_prefix": "VIMFIX"})
@click.version_option(message=header)
@click.option(
    "-d",
    "--debug",
    is_eager=True,
    is_flag=True,
    callback=_ehandler,
    help="debug mode",
)
@click.option(
    "--shell-completion",
    is_flag=False,
    flag_value="[auto]",
    callback=_shell_completion,
    help="configure shell completion",
)
@click.option("-q", "--quiet", is_flag=True, help="no echo stdout")
@click.option("-E", "--ignore-stderr", is_flag=True, help="ignore stderr when scanning")
@click.option("-O", "--ignore-stdout", is_flag=True, help="ignore stdout when scanning")
@click.option(
    "-s/-S",
    "--strip/--no-strip",
    is_flag=True,
    default=True,
    help="strip ANSI codes",
)
@click.option(
    "-f",
    "--format",
    "fmt",
    type=click.Choice(list(formats.keys())),
)
@click.option(
    "-o",
    "--output",
    type=click.Path(dir_okay=False, writable=True, path_type=Path),
)
@click.argument("command")
@click.pass_context
def cli(
    ctx,
    debug,
    shell_completion,
    quiet,
    ignore_stderr,
    ignore_stdout,
    strip,
    fmt,
    output,
    command,
):
    if fmt is None:
        for _fmt in formats.keys():
            if command.split()[0] == _fmt:
                fmt = _fmt
                break
    if not fmt:
        fmt = formats.keys()[0]

    vimfix(command, quiet, ignore_stderr, ignore_stdout, strip, fmt, output)


if __name__ == "__main__":
    sys.exit(cli())  # pragma: no cover
